LicenseValidator

Struct LicenseValidator 

pub struct LicenseValidator { /* private fields */ }
License key validator for offline validation

Implementations

Source

impl LicenseValidator

pub fn new<S: Into<String>>(secret_key: S) -> Self

Create a new license validator with the provided secret key

Arguments
  • secret_key - The same secret key used for generation
Example
use alvan_lic::LicenseValidator;
let validator = LicenseValidator::new("my-secret-key");
pub fn validate_key(&self, license_key: &str) -> Result<LicenseInfo>

Validate a license key

Arguments
  • license_key - The license key to validate
Returns

LicenseInfo if the license is valid, or an error

Example
use alvan_lic::{LicenseGenerator, LicenseValidator};
 
let secret = "secret-key";
let generator = LicenseGenerator::new(secret);
let validator = LicenseValidator::new(secret);
 
let license = generator.generate_key(24).unwrap();
let info = validator.validate_key(&license).unwrap();
assert!(info.is_valid);
pub fn validate_key_at_time( &self, license_key: &str, current_time: DateTime<Utc>, ) -> Result<LicenseInfo>

Validate a license key at a specific time (useful for testing)